summaryrefslogtreecommitdiffstats
path: root/src/sound/MappedStudio.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/sound/MappedStudio.cpp')
-rw-r--r--src/sound/MappedStudio.cpp70
1 files changed, 35 insertions, 35 deletions
diff --git a/src/sound/MappedStudio.cpp b/src/sound/MappedStudio.cpp
index 9911b67..e5a583c 100644
--- a/src/sound/MappedStudio.cpp
+++ b/src/sound/MappedStudio.cpp
@@ -185,21 +185,21 @@ const MappedObjectProperty MappedPluginPort::Value = "value";
void
MappedObject::addChild(MappedObject *object)
{
- std::vector<MappedObject*>::iterator it = m_children.begin();
- for (; it != m_children.end(); it++)
+ std::vector<MappedObject*>::iterator it = m_tqchildren.begin();
+ for (; it != m_tqchildren.end(); it++)
if ((*it) == object)
return ;
- m_children.push_back(object);
+ m_tqchildren.push_back(object);
}
void
MappedObject::removeChild(MappedObject *object)
{
- std::vector<MappedObject*>::iterator it = m_children.begin();
- for (; it != m_children.end(); it++) {
+ std::vector<MappedObject*>::iterator it = m_tqchildren.begin();
+ for (; it != m_tqchildren.end(); it++) {
if ((*it) == object) {
- m_children.erase(it);
+ m_tqchildren.erase(it);
return ;
}
}
@@ -211,9 +211,9 @@ MappedObjectPropertyList
MappedObject::getChildren()
{
MappedObjectPropertyList list;
- std::vector<MappedObject*>::iterator it = m_children.begin();
- for (; it != m_children.end(); it++)
- list.push_back(TQString("%1").arg((*it)->getId()));
+ std::vector<MappedObject*>::iterator it = m_tqchildren.begin();
+ for (; it != m_tqchildren.end(); it++)
+ list.push_back(TQString("%1").tqarg((*it)->getId()));
return list;
}
@@ -225,10 +225,10 @@ MappedObjectPropertyList
MappedObject::getChildren(MappedObjectType type)
{
MappedObjectPropertyList list;
- std::vector<MappedObject*>::iterator it = m_children.begin();
- for (; it != m_children.end(); it++) {
+ std::vector<MappedObject*>::iterator it = m_tqchildren.begin();
+ for (; it != m_tqchildren.end(); it++) {
if ((*it)->getType() == type)
- list.push_back(TQString("%1").arg((*it)->getId()));
+ list.push_back(TQString("%1").tqarg((*it)->getId()));
}
return list;
@@ -244,16 +244,16 @@ MappedObject::destroyChildren()
// see note in destroy() below
- std::vector<MappedObject *> children = m_children;
- m_children.clear();
+ std::vector<MappedObject *> tqchildren = m_tqchildren;
+ m_tqchildren.clear();
- std::vector<MappedObject *>::iterator it = children.begin();
- for (; it != children.end(); it++)
+ std::vector<MappedObject *>::iterator it = tqchildren.begin();
+ for (; it != tqchildren.end(); it++)
(*it)->destroy(); // remove from studio and destroy
}
// Destroy this object and remove it from the studio and
// do the same for all its children.
//
void
MappedObject::destroy()
@@ -268,14 +268,14 @@ MappedObject::destroy()
// which calls back on the parent (in this case us) to remove the
// child. (That's necessary for the case of destroying a plugin,
// where we need to remove it from its plugin manager -- etc.) So
// we don't want to be iterating over m_children here, as it will
// change from under us.
- std::vector<MappedObject *> children = m_children;
- m_children.clear();
+ std::vector<MappedObject *> tqchildren = m_tqchildren;
+ m_tqchildren.clear();
- std::vector<MappedObject *>::iterator it = children.begin();
- for (; it != children.end(); it++) {
+ std::vector<MappedObject *>::iterator it = tqchildren.begin();
+ for (; it != tqchildren.end(); it++) {
(*it)->destroy();
}
@@ -875,30 +875,30 @@ MappedAudioFader::getPropertyList(const MappedObjectProperty &property)
list.push_back(MappedConnectableObject::ConnectionsIn);
list.push_back(MappedConnectableObject::ConnectionsOut);
} else if (property == MappedObject::Instrument) {
- list.push_back(MappedObjectProperty("%1").arg(m_instrumentId));
+ list.push_back(MappedObjectProperty("%1").tqarg(m_instrumentId));
} else if (property == MappedAudioFader::FaderLevel) {
- list.push_back(MappedObjectProperty("%1").arg(m_level));
+ list.push_back(MappedObjectProperty("%1").tqarg(m_level));
} else if (property == MappedAudioFader::FaderRecordLevel) {
- list.push_back(MappedObjectProperty("%1").arg(m_recordLevel));
+ list.push_back(MappedObjectProperty("%1").tqarg(m_recordLevel));
} else if (property == MappedAudioFader::Channels) {
- list.push_back(MappedObjectProperty("%1").arg(m_channels));
+ list.push_back(MappedObjectProperty("%1").tqarg(m_channels));
} else if (property == MappedAudioFader::InputChannel) {
- list.push_back(MappedObjectProperty("%1").arg(m_inputChannel));
+ list.push_back(MappedObjectProperty("%1").tqarg(m_inputChannel));
} else if (property == MappedAudioFader::Pan) {
- list.push_back(MappedObjectProperty("%1").arg(m_pan));
+ list.push_back(MappedObjectProperty("%1").tqarg(m_pan));
} else if (property == MappedConnectableObject::ConnectionsIn) {
MappedObjectValueList::const_iterator
it = m_connectionsIn.begin();
for ( ; it != m_connectionsIn.end(); ++it) {
- list.push_back(TQString("%1").arg(*it));
+ list.push_back(TQString("%1").tqarg(*it));
}
} else if (property == MappedConnectableObject::ConnectionsOut) {
MappedObjectValueList::const_iterator
it = m_connectionsOut.begin();
for ( ; it != m_connectionsOut.end(); ++it) {
- list.push_back(TQString("%1").arg(*it));
+ list.push_back(TQString("%1").tqarg(*it));
}
}
@@ -1013,22 +1013,22 @@ MappedAudioBuss::getPropertyList(const MappedObjectProperty &property)
list.push_back(MappedConnectableObject::ConnectionsIn);
list.push_back(MappedConnectableObject::ConnectionsOut);
} else if (property == BussId) {
- list.push_back(MappedObjectProperty("%1").arg(m_bussId));
+ list.push_back(MappedObjectProperty("%1").tqarg(m_bussId));
} else if (property == Level) {
- list.push_back(MappedObjectProperty("%1").arg(m_level));
+ list.push_back(MappedObjectProperty("%1").tqarg(m_level));
} else if (property == MappedConnectableObject::ConnectionsIn) {
MappedObjectValueList::const_iterator
it = m_connectionsIn.begin();
for ( ; it != m_connectionsIn.end(); ++it) {
- list.push_back(TQString("%1").arg(*it));
+ list.push_back(TQString("%1").tqarg(*it));
}
} else if (property == MappedConnectableObject::ConnectionsOut) {
MappedObjectValueList::const_iterator
it = m_connectionsOut.begin();
for ( ; it != m_connectionsOut.end(); ++it) {
- list.push_back(TQString("%1").arg(*it));
+ list.push_back(TQString("%1").tqarg(*it));
}
}
@@ -1152,7 +1152,7 @@ MappedAudioInput::getPropertyList(const MappedObjectProperty &property)
if (property == "") {
list.push_back(MappedAudioInput::InputNumber);
} else if (property == InputNumber) {
- list.push_back(MappedObjectProperty("%1").arg(m_inputNumber));
+ list.push_back(MappedObjectProperty("%1").tqarg(m_inputNumber));
}
return list;
@@ -244,16 +244,16 @@ MappedObject::destroyChildren()
}
// Destroy this object and remove it from the studio and
-// do the same for all its children.
+// do the same for all its tqchildren.
//
void
@@ -268,14 +268,14 @@ MappedObject::destroy()
// child. (That's necessary for the case of destroying a plugin,
// where we need to remove it from its plugin manager -- etc.) So
- // we don't want to be iterating over m_children here, as it will
+ // we don't want to be iterating over m_tqchildren here, as it will
// change from under us.